﻿import LensManager from '/core/ui/lenses/lens-manager.js';

const logPrefix = "Off The Grid (Finwickle): ";

class offTheGridSingleton {
    static getInstance() {
        if (!offTheGridSingleton.singletonInstance) {
            offTheGridSingleton.singletonInstance = new offTheGridSingleton();
        }
        return offTheGridSingleton.singletonInstance;
    }
    constructor() {
        engine.whenReady.then(() => { this.onReady(); });
    }
	onReady() {
		// run when UI is loaded, including UI reloads
		window.addEventListener("user-interface-loaded-and-ready", this.onGameLoaded.bind(this)); // This has a 1 second delay.
	}
	onGameLoaded() {
		this.disableHexGridEverywhere();
	}
    disableHexGridEverywhere() {
		// this may give the following warnings in the UI.log:
		//    aquire tile lens: Argument conversion failed: Wrong type [...] While executing [...] worker-yields-layer.js
		//    building placement lens: No assigned cityID in the BuildingPlacementManager when attempting to realizeBuildingPlacementSprites 
		//    founder and settler lenses: Unable to find random event data for CLASS_ERUPTION (multiple)
		// save active lens
		const prevLens = LensManager.getActiveLens();
		// disable hex grid on all lenses
		console.warn(logPrefix + 'disabling hex grid on all lenses.  This may give innocent warnings about "Argument conversion failed", "No assigned cityID" and "random event data for CLASS_ERUPTION".');
		for (const lensType of LensManager.lenses.keys()) {
			if (LensManager.setActiveLens(lensType) && LensManager.isLayerEnabled('fxs-hexgrid-layer')) {
				LensManager.toggleLayer('fxs-hexgrid-layer', false);
				console.warn(logPrefix + "hex grid disabled for " + lensType);
			}
			else {
				console.warn(logPrefix + "grid was already disabled for " + lensType);
			}
		}
		// switch back to previous lens
		LensManager.setActiveLens(prevLens);
        console.warn(logPrefix + "finished.");
    }
}

// Create mod instance
const offTheGrid = offTheGridSingleton.getInstance();
export { offTheGrid as default };
